==> eiffelstudio-18.01.10.1424.tar: F_code/C49/vw2437.c <==
/*
 * Code for class VWMA_NO_CLASS_TYPE
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "vw2437.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {VWMA_NO_CLASS_TYPE}.make */
void F3385_38682 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3)
{
	GTCX
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,arg3);
	RTLR(2,Current);
	RTLR(3,arg2);
	RTLIU(4);
	
	RTGC;
	{
		/* INLINED CODE (make_parent) */
		F3657_43288(RTCW(arg1), Current);
		F3113_37554(Current, arg3);
		/* END INLINED CODE */
	}
	;
	RTAR(Current, arg2);
	*(EIF_REFERENCE *)(Current + _REFACS_7_) = (EIF_REFERENCE) arg2;
	RTLE;
}

/* {VWMA_NO_CLASS_TYPE}.type */
EIF_REFERENCE F3385_38683 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_7_);
}


/* {VWMA_NO_CLASS_TYPE}.build_explain */
void F3385_38684 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTLD;
	
	RTLI(2);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTGC;
	F3385_38685(Current, arg1);
	{
		/* INLINED CODE (add_new_line) */
		(FUNCTION_CAST(void, (EIF_REFERENCE)) R14545[Dtype(arg1)-1902])(RTCW(arg1));
		/* END INLINED CODE */
	}
	;
	RTLE;
}

/* {VWMA_NO_CLASS_TYPE}.trace_single_line */
void F3385_38685 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_REFERENCE tr4 = NULL;
	EIF_REFERENCE tr5 = NULL;
	EIF_REFERENCE tr6 = NULL;
	EIF_REFERENCE tr7 = NULL;
	RTCFDT;
	RTLD;
	
	RTLI(9);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,tr2);
	RTLR(4,tr3);
	RTLR(5,tr4);
	RTLR(6,tr5);
	RTLR(7,tr6);
	RTLR(8,tr7);
	RTLIU(9);
	
	RTGC;
	tr1 = F2940_34173(Current);
	tr2 = RTMS_EX_H("Manifest array type {1} is not a class type.",44,760537902);
	tr3 = RTMS_EX_H("compiler.error",14,1616564082);
	tr1 = F109_2138(RTCW(tr1), tr2, tr3);
	{
		static EIF_TYPE_INDEX typarr0[] = {1812,2129,0xFFF9,1,1971,1901,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr3 = RTLNSP2(typres0.id,EO_REF,((EIF_INTEGER_32) 1L),sizeof(EIF_REFERENCE), EIF_FALSE);
		RT_SPECIAL_COUNT(tr3) = 1L;
		memset(tr3, 0, RT_SPECIAL_VISIBLE_SIZE(tr3));
	}
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFFF9,1,1971,2497,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr4 = RTLNTS(typres0.id, 2, 0);
	}
	tr5 = *(EIF_REFERENCE *)(Current + _REFACS_7_);
	((EIF_TYPED_VALUE *)tr4+1)->it_r = tr5;
	RTAR(tr4,tr5);
	
	{
		static EIF_TYPE_INDEX typarr0[] = {2129,0xFFF9,1,1971,1901,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr7 = RTLNRF(typres0.id, (EIF_POINTER) __A1594_322_2, (EIF_POINTER) _A1594_322_2, (EIF_POINTER)(F2498_28105),tr4, 1, 1);
	}
	*((EIF_REFERENCE *)tr3+0) = (EIF_REFERENCE) tr7;
	RTAR(tr3,tr7);
	tr2 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) F1813_17350)(tr3);
	F419_6139(Current, arg1, tr1, tr2);
	RTLE;
}

void EIF_Minit2437 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.07.10.1981.tar: F_code/C49/vw2437.c <==
/*
 * Code for class VWMA_SEPARATE_ARRAY
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "vw2437.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {VWMA_SEPARATE_ARRAY}.make */
void F3391_38869 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3)
{
	GTCX
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,arg3);
	RTLR(2,Current);
	RTLR(3,arg2);
	RTLIU(4);
	
	RTGC;
	{
		/* INLINED CODE (make_parent) */
		F3668_43510(RTCW(arg1), Current);
		F3125_37759(Current, arg3);
		/* END INLINED CODE */
	}
	;
	RTAR(Current, arg2);
	*(EIF_REFERENCE *)(Current + _REFACS_7_) = (EIF_REFERENCE) arg2;
	RTLE;
}

/* {VWMA_SEPARATE_ARRAY}.type */
EIF_REFERENCE F3391_38870 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_7_);
}


/* {VWMA_SEPARATE_ARRAY}.build_explain */
void F3391_38871 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTLD;
	
	RTLI(2);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTGC;
	F3391_38872(Current, arg1);
	{
		/* INLINED CODE (add_new_line) */
		(FUNCTION_CAST(void, (EIF_REFERENCE)) R14664[Dtype(arg1)-1915])(RTCW(arg1));
		/* END INLINED CODE */
	}
	;
	RTLE;
}

/* {VWMA_SEPARATE_ARRAY}.trace_single_line */
void F3391_38872 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_REFERENCE tr4 = NULL;
	EIF_REFERENCE tr5 = NULL;
	EIF_REFERENCE tr6 = NULL;
	EIF_REFERENCE tr7 = NULL;
	RTCFDT;
	RTLD;
	
	RTLI(9);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,tr2);
	RTLR(4,tr3);
	RTLR(5,tr4);
	RTLR(6,tr5);
	RTLR(7,tr6);
	RTLR(8,tr7);
	RTLIU(9);
	
	RTGC;
	tr1 = F2956_34365(Current);
	tr2 = RTMS_EX_H("Manifest array type {1} is separate.",36,1814278190);
	tr3 = RTMS_EX_H("compiler.error",14,1616564082);
	tr1 = F112_2166(RTCW(tr1), tr2, tr3);
	{
		static EIF_TYPE_INDEX typarr0[] = {1825,2142,0xFFF9,1,1984,1914,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr3 = RTLNSP2(typres0.id,EO_REF,((EIF_INTEGER_32) 1L),sizeof(EIF_REFERENCE), EIF_FALSE);
		RT_SPECIAL_COUNT(tr3) = 1L;
		memset(tr3, 0, RT_SPECIAL_VISIBLE_SIZE(tr3));
	}
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFFF9,1,1984,2510,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr4 = RTLNTS(typres0.id, 2, 0);
	}
	tr5 = *(EIF_REFERENCE *)(Current + _REFACS_7_);
	((EIF_TYPED_VALUE *)tr4+1)->it_r = tr5;
	RTAR(tr4,tr5);
	
	{
		static EIF_TYPE_INDEX typarr0[] = {2142,0xFFF9,1,1984,1914,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr7 = RTLNRF(typres0.id, (EIF_POINTER) __A1601_343_2, (EIF_POINTER) _A1601_343_2, (EIF_POINTER)(F2511_28261),tr4, 1, 1);
	}
	*((EIF_REFERENCE *)tr3+0) = (EIF_REFERENCE) tr7;
	RTAR(tr3,tr7);
	tr2 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) F1826_17480)(tr3);
	F532_7376(Current, arg1, tr1, tr2);
	RTLE;
}

void EIF_Minit2437 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
